@@ -13,8 +13,8 @@ kc = TracingKafkaConsumer({'group.id': 'cg-1'}, tracer)
 class TestTracingKafkaConsumer(unittest.TestCase):
     def test_should_build_and_finish_child_span(self):
         msg = MockMessage(key='key', value='value',
-                          headers=[(field_name_trace_id, format(1, 'x')), (field_name_span_id, format(101, 'x')),
-                                   ('key1', 'val1')],
+                          headers=[(field_name_trace_id, b'1'), (field_name_span_id, b'101'),
+                                   ('key1', b'val1')],
                           topic='topic', partition=0, offset=23)
 
         kc.build_and_finish_child_span(msg)
